Overview – Samplics Documentation
Description: Documentation of the Python package Samplics for statistical design and analysis of complex samples

# Overview

Categorical data analysis refers to the set of methods for analyzing categorical response variables. This is a large topic in data analysis and used in the context of complex survey sampling. Contingency tables or cross-tabulations with associated statistics are well-known categorical data analysis techniques. But categorical data analysis extends to more areas such as modeling techniques for categorical response variables e.g. logistic/logit/loglinear regressions and generalized linear mixed models for categorical responses.

Section 1: Tabulation
Section 2: T-Test

Agresti (2013) provides an overview of these methods.

## References

Agresti, Alan. 2013. Categorical Data Analysis, 3rd edn. John Wiley & Sons, Hoboken, New Jersey.